==> org.eclipse.app4mc.amalthea.model.editor.contribution.source_2.0.0.202109301305.jar: org/eclipse/app4mc/amalthea/model/editor/contribution/handler/ProcessModelStructureHandler.java <==
/*********************************************************************************
 * Copyright (c) 2021 Robert Bosch GmbH and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Robert Bosch GmbH - initial API and implementation
 ********************************************************************************
 */ 

package org.eclipse.app4mc.amalthea.model.editor.contribution.handler;

import javax.annotation.PostConstruct;
import javax.inject.Named;

import org.eclipse.app4mc.amalthea.model.editor.contribution.registry.ProcessingServiceRegistry;
import org.eclipse.app4mc.amalthea.model.editor.contribution.registry.RegistryServiceWrapper;
import org.eclipse.app4mc.amalthea.model.editor.contribution.service.ProcessingService;
import org.eclipse.e4.core.contexts.ContextInjectionFactory;
import org.eclipse.e4.core.contexts.IEclipseContext;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.core.di.extensions.Service;
import org.eclipse.e4.ui.services.IServiceConstants;
import org.eclipse.emf.common.notify.Notifier;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.change.util.ChangeRecorder;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.emf.edit.command.ChangeCommand;
import org.eclipse.emf.edit.domain.AdapterFactoryEditingDomain;
import org.eclipse.emf.edit.domain.EditingDomain;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Shell;

@SuppressWarnings("restriction")
public class ProcessModelStructureHandler {

	@Execute
	public void execute(
			Shell shell,
			@Named("app4mc.creator.model") String modelType,
			@Named("app4mc.creator.id") String creatorId,
			@Named(IServiceConstants.ACTIVE_SELECTION) IStructuredSelection selection,
			@Service ProcessingServiceRegistry registry,
			IEclipseContext context) {
		
		RegistryServiceWrapper<ProcessingService> processor = registry.getService(modelType, creatorId);
		if (selection.getFirstElement() instanceof EObject && processor != null) {
			EObject object = (EObject) selection.getFirstElement();
			
			EObject rootContainer = EcoreUtil.getRootContainer(object);
			
			// Use ChangeCommand and CommandStack to execute changes
			
			EditingDomain editingDomain = AdapterFactoryEditingDomain.getEditingDomainFor(rootContainer);
			ChangeCommandWithStatusResult command = new ChangeCommandWithStatusResult(
					new ChangeRecorder(), rootContainer, context,
					modelType, processor, object);

			String[] split = processor.getName().split("\\|");
			command.setLabel(split[split.length-1].trim());
			
			editingDomain.getCommandStack().execute(command);
			
			// Display result
			if (command.status != null) {
				MessageDialog.openInformation(shell, "AMALTHEA Model Processing", command.status.toString());
			}
		}
	}
	
	private class ChangeCommandWithStatusResult extends ChangeCommand {
		
		IEclipseContext context;
		String modelType;
		RegistryServiceWrapper<ProcessingService> processor;
		EObject object;
		
		Object status;
		
		public ChangeCommandWithStatusResult(
				ChangeRecorder changeRecorder, Notifier notifier, IEclipseContext context,
				String modelType, RegistryServiceWrapper<ProcessingService> processor, EObject object) {
			
			super(changeRecorder, notifier);
			this.context = context;
			this.modelType = modelType;
			this.processor = processor;
			this.object = object;
		}

		@Override
		protected void doExecute() {
			// *** execute specific processing actions here ***
			IEclipseContext activeContext = context.createChild(modelType + " ProcessingModelStructure");
			activeContext.set(processor.getType(), object);
			
			try {
				this.status = ContextInjectionFactory.invoke(processor.getServiceInstance(), PostConstruct.class, activeContext);
			} finally {
				// dispose the context after the execution to avoid memory leaks
				activeContext.dispose();
			}
		}
	}
}

==> org.eclipse.app4mc.amalthea.model.editor.contribution.source_3.0.0.202208031001.jar: org/eclipse/app4mc/amalthea/model/editor/contribution/handler/ProcessModelStructureHandler.java <==
/*********************************************************************************
 * Copyright (c) 2021-2022 Robert Bosch GmbH and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Robert Bosch GmbH - initial API and implementation
 ********************************************************************************
 */

package org.eclipse.app4mc.amalthea.model.editor.contribution.handler;

import javax.inject.Named;

import org.eclipse.app4mc.amalthea.model.editor.contribution.registry.ProcessingServiceRegistry;
import org.eclipse.app4mc.amalthea.model.editor.contribution.registry.RegistryServiceWrapper;
import org.eclipse.app4mc.amalthea.model.editor.contribution.service.ProcessingService;
import org.eclipse.e4.core.contexts.IEclipseContext;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.core.di.extensions.Service;
import org.eclipse.e4.ui.services.IServiceConstants;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.emf.edit.domain.AdapterFactoryEditingDomain;
import org.eclipse.emf.edit.domain.EditingDomain;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Shell;

public class ProcessModelStructureHandler {

	@Execute
	public void execute(
			Shell shell,
			@Named("app4mc.creator.model") String modelType,
			@Named("app4mc.creator.id") String creatorId,
			@Named(IServiceConstants.ACTIVE_SELECTION) IStructuredSelection selection,
			@Service ProcessingServiceRegistry registry,
			IEclipseContext context) {

		RegistryServiceWrapper<ProcessingService> serviceWrapper = registry.getService(modelType, creatorId);

		if (selection.getFirstElement() instanceof EObject && serviceWrapper != null) {
			EObject eObject = (EObject) selection.getFirstElement();
			EObject rootContainer = EcoreUtil.getRootContainer(eObject);

			// Use ChangeCommand and CommandStack to execute changes

			EditingDomain editingDomain = AdapterFactoryEditingDomain.getEditingDomainFor(rootContainer);
			ChangeCommandWithStatusResult<ProcessingService> command = new ChangeCommandWithStatusResult<>(
					rootContainer, context, modelType + " ProcessingModelStructure", serviceWrapper, eObject);

			String[] split = serviceWrapper.getName().split("\\|");
			command.setLabel(split[split.length-1].trim());

			editingDomain.getCommandStack().execute(command);

			// Display result
			if (command.status != null) {
				MessageDialog.openInformation(shell, "AMALTHEA Model Processing", command.status.toString());
			}
		}
	}

}
